//
//  AASDirectoryFilter.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/11/08.
//  OS X 10.5 or later required.
/* Copyright (c) 2001-2009, Andreas Schwarz
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 Neither the names of the Andreas Schwarz or immaterial nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* This AASFileFilter subclass is used by the AASRecursiveFileLoadOperation to determine if a particular file should be included as a directory. However, in addition to the standard filter method, AASDirectoryFilter includes a method which returns a file object for the 'true' directory which is called if -shouldIncludeFileItem: returns yes. Subclasses which override -shouldIncludeFileItem: to include things such as symbolic links and aliases to directories should pass an object representing the 'real' directory here. */


#import <Cocoa/Cocoa.h>
#import "AASFileFilter.h"

@class AASFileItem;

@interface AASDirectoryFilter : AASFileFilter {
	SEL trueDirectorySelector;
}

/* Should return YES if the file item should be considered a directory, NO if not. For example, you may want to treat packages as regular files rather than directories, and so set up your filterSelector to include normal folders but not packages. The default implementation returns YES or NO based on the -isBasicDirectory method of 'file'. */ 
- (BOOL)shouldIncludeFileItem:(AASFileItem *)file;

/* Called to get the file item for the 'true' directory that 'file' points to. For example, if you want to treat aliases to folders as folders, your filterSelector would return YES for aliases to folders, then your trueDirectorySelector would return the file item for the actual folder (rather than the file item for the alias). The default implementation just returns 'file'. */
- (AASFileItem *)trueDirectoryItemForFileItem:(AASFileItem *)file;

/* Selector that will be called on targetClass to get the file item for the 'true' directory. Takes a file item as an argument and should return a file item. */
@property(assign) SEL trueDirectorySelector;


@end
